@@ -13,7 +13,7 @@ from .errors import APIKeyVerificationError, InvalidOperationError, LucidicNotIn
 from .telemetry.base_provider import BaseProvider 
 from .session import Session
 from .singleton import singleton, clear_singletons
-
+from .lru import LRUCache
 
 NETWORK_RETRIES = 3
 
@@ -22,14 +22,16 @@ NETWORK_RETRIES = 3
 class Client:
     def __init__(
         self,
-        lucidic_api_key: str,
+        api_key: str,
         agent_id: str,
     ):
         self.base_url = "https://analytics.lucidic.ai/api" if not (os.getenv("LUCIDIC_DEBUG", 'False') == 'True') else "http://localhost:8000/api"
         self.initialized = False
         self.session = None
+        self.previous_sessions = LRUCache(500)  # For LRU cache of previously initialized sessions
+        self.custom_session_id_translations = LRUCache(500) # For translations of custom session IDs to real session IDs
         self.providers = []
-        self.api_key = lucidic_api_key
+        self.api_key = api_key
         self.agent_id = agent_id
         self.masking_function = None
         self.auto_end = False  # Default to False until explicitly set during init
@@ -42,13 +44,17 @@ class Client:
         )
         adapter = HTTPAdapter(max_retries=retry_cfg, pool_connections=20, pool_maxsize=100)
         self.request_session.mount("https://", adapter)
-        self.request_session.headers.update({"Authorization": f"Api-Key {self.api_key}", "User-Agent": "lucidic-sdk/1.1"})
+        self.set_api_key(api_key)
         self.prompts = dict()
+
+    def set_api_key(self, api_key: str):
+        self.api_key = api_key
+        self.request_session.headers.update({"Authorization": f"Api-Key {self.api_key}", "User-Agent": "lucidic-sdk/1.1"})
         try:
-            self.verify_api_key(self.base_url, lucidic_api_key)
+            self.verify_api_key(self.base_url, api_key)
         except APIKeyVerificationError:
             raise APIKeyVerificationError("Invalid API Key")
-    
+
     def clear(self):
         self.undo_overrides()
         clear_singletons()
@@ -69,7 +75,7 @@ class Client:
     def undo_overrides(self):
         for provider in self.providers:
             provider.undo_override()
-    
+
     def init_session(
         self,
         session_name: str,
@@ -78,30 +84,69 @@ class Client:
         rubrics: Optional[list] = None,
         tags: Optional[list] = None,
         production_monitoring: Optional[bool] = False,
-        custom_session_id: Optional[str] = None,
+        session_id: Optional[str] = None,
     ) -> None:
+        if session_id:
+            # Check if it's a known session ID, maybe custom and maybe real
+            if session_id in self.custom_session_id_translations:
+                session_id = self.custom_session_id_translations[session_id]
+            # Check if it's the same as the current session
+            if self.session and self.session.session_id == session_id:
+                return self.session.session_id
+            # Check if it's a previous session that we have saved
+            if session_id in self.previous_sessions:
+                if self.session:
+                    self.previous_sessions[self.session.session_id] = self.session
+                self.session = self.previous_sessions.pop(session_id)  # Remove from previous sessions because it's now the current session
+                return self.session.session_id
+
+        # Either there's no session ID, or we don't know about the old session
+        # We need to go to the backend in both cases
+        request_data = {
+            "agent_id": self.agent_id,
+            "session_name": session_name,
+            "task": task,
+            "mass_sim_id": mass_sim_id,
+            "rubrics": rubrics,
+            "tags": tags,
+            "session_id": session_id
+        }
+        data = self.make_request('initsession', 'POST', request_data)
+        real_session_id = data["session_id"]
+        if session_id and session_id != real_session_id:
+            self.custom_session_id_translations[session_id] = real_session_id
+        
+        if self.session:
+            self.previous_sessions[self.session.session_id] = self.session
+
         self.session = Session(
             agent_id=self.agent_id,
+            session_id=real_session_id,
             session_name=session_name,
             mass_sim_id=mass_sim_id,
             task=task,
             rubrics=rubrics,
             tags=tags,
-            production_monitoring=production_monitoring,
-            custom_session_id=custom_session_id
         )
         self.initialized = True
         return self.session.session_id
 
     def continue_session(self, session_id: str):
+        if session_id in self.custom_session_id_translations:
+            session_id = self.custom_session_id_translations[session_id]
+        if self.session and self.session.session_id == session_id:
+            return self.session.session_id
+        if self.session:
+            self.previous_sessions[self.session.session_id] = self.session
+        data = self.make_request('continuesession', 'POST', {"session_id": session_id})
+        real_session_id = data["session_id"]
+        if session_id != real_session_id:
+            self.custom_session_id_translations[session_id] = real_session_id
         self.session = Session(
             agent_id=self.agent_id,
-            session_id=session_id
+            session_id=real_session_id
         )
-        if self.session.session_id != session_id:
-            # Custom session ID provided
-            self.session.custom_session_id = session_id
-        self.initialized = True
+        logger.info(f"Session {data.get('session_name', '')} continuing...")
         return self.session.session_id
 
     def init_mass_sim(self, **kwargs) -> str:
